#ifndef __201CVI_H     /* prevent multiple includes */
#define __201CVI_H

/****** MACROS *******************************/
/*-------------------------------------------*/
/* platform dependent */
#define COM_DEF "COM"
#define CLK_TCK 1000

/* global use macros */
#define TRUE -1
#define FALSE 0
#define BOOL unsigned int

#define BYTE unsigned char
#define DWORD unsigned int

/* communication constants */
#define PARITY 0  	/* parity = none */
#define DATA_BITS 8 	/* 8 data bits */
#define STOP_BITS 1 	/* 1 stop bit */

/* current acquisisition status. ie: IS_RUNNING, NOT_RUNNING, IDLE */
#define NOT_RUNNING 	0       /* main panel LED status */
#define IS_RUNNING 	1       /* main panel LED status */
#define IDLE 			2       /* main panel LED status */
int acquireStat;

#define HIDE_BUTTON  FALSE   /* hide OK button in panels */
#define SHOW_BUTTON  TRUE    /* show OK button in panels */


/* scan status return values */
#define SCAN_DONE 0
#define SCAN_NOT_DONE 1
#define SCAN_TIMEOUT 2

char scanStatus;	
double requestedScanInterval;
double maxTime, minTime;

char activeSubChannel;
char activeChannelIndex;
char activeChannel;

int scanWords, i;
static char gotFrameStart;
double scanArrayIndex;
double  scanDataArray[97];

#define NO_LED 0
#define GREEN_LED 1
#define YELLOW_LED 2
#define RED_LED 3
char scanStatLED;

/* used by mode selector on main panel to hold value of current mode of operation */
#define POLLED_MODE 0
#define SINGLE_SCAN_MODE 		1
#define MULTI_SCAN_MODE 		2
#define MULTI_SCAN_CAL_MODE 	3
	
int curQLen = 0;
int numPlotPoint;
/* temporary storage for mode type while changing mode */
int modeType;

/* current mode of operations */
int opMode;

int errByte;
int errBuff[80];
int errBuff2[80];
int errBuffCnt;

char setupOpenedFlg;
char ConvPendingFlg;

#define EVENT_NOT_PENDING 0
#define EVENT_PENDING 1
char eventPendingFlg;

char 	errorMsg201CVI[220];
char	scratchBuff[180];

BYTE b, cbuf[25];

double fTime;

typedef struct{
	short	comPort;
	double	scanInterval;
	short	numChannels;
	short	tScan;
	short	chan[6];
	short	singleChan;
	short   lastDigInp;
	short 	version;
	short 	channel;
	short 	subChan;
	long	rawCount;
	double	voltage;
	int 	digOutWord;
	short 	wordCnt;
	short 	biPolar;
	int 	errorType;
	short 	filter;
	short 	gain;
	float 	rate;
	short 	modeRegLo;
	short 	modeRegMid;
	short 	modeRegHi;
	short	baud;
	short	sleeping;
	short	standBy;
	int		timeBaseCnt;
	unsigned int    average;
	unsigned int    TXQUEUESIZE;
	unsigned int    RXQUEUESIZE;
}	T_M201;

#define FRAME_START 0
#define FRAME_END 1
int CheckScanFrame(int framePos);

/*calculated conversion wait time */
double ConvWait;
/*  input buffer and size */
int buffer_size;

void   WriteCntr(T_M201 *M201, int cntPort, int cntrCount);
int CalcVoltage(void);


/****** EXTERNAL FUNCTION PROTOTYPES *********/
/*-------------------------------------------*/
extern char* test(void);
/*********************************************/


/****** DRIVER FUNCTION PROTOTYPES ***********/
/*-------------------------------------------*/

void SendPacket (int Outb1, int Outb2);
void WaitXX(float xx);
int  WaitChar(int chars,float zz,BYTE *c);

/* send cancel command while in polled loop  */
int SendCancel(void);

/*Set the filter  0 = 4 Hz   1 = 40 Hz   2 = 400 Hz */
void   SetFilter(short filter);

/* calculate settling and conversion wait times */
void CalcWait(void); 

/*This function will sign on to the Model 201 using the settings in M201 */
/*If could not sign on, closes port and returns 0. Otherwise, returns 1, */
/*port is open and the Model 201 is active. */
short	 SignOn(T_M201 *M201, int(*setMsgRuntimePtr)(char*));

/*take a raw count and scale in volts */
double Counts2Volts(long counts,
								short wordCnt,
								short biBolar);

/*Get a digital input from the Model 201.  Returns 0 if Model 201 did not */
/*echo back the Get Digital Input token. */
short  GetDigIn(T_M201 *M201);

/*Get the Model 201 version.  Returns 0 if Model 201 did not echo back the */
/*version token. */
short  GetVer(T_M201 *M201);

/*Send a digital output to the Model 201 */
short  SetDigOut(int digOutWord);

/*Set averaging in the Model 201 (powers of 2) */
short  RemoteAvg(T_M201 *M201);

/*Perform a full scale calibration on the currently selected channel */
short  FullScaleCal(T_M201 *M201);

/*Perform an offset calibration on the currently selected channel */
short  OffsetCal(T_M201 *M201);

/*Perform a system calibration (full scale on channel 6, offset on channel 7) */
short  SysCal(T_M201 *M201);

/*Get a conversion from the Model 201 on the currently selected channel */
short  StartConversion(T_M201 *M201);

/*Get a conversion from the Model 201 on the currently selected channel */
short  RequestAnswer(T_M201 *M201);

/*Select channel and subchannel from M201.channel and M201.subChan */
short  SetChanCode(T_M201 *M201);

/*Start scanning using selected scan type. Returns 0 if scan token is not */
/*echoed back. */
short  StartScanning(T_M201 *M201);

/*Get one scan from currently selected comm port buffer. It will wait the */
/*calculated time for the scan to come in. Returns 0 if failed. Returns type */
/*of failure in M201.errorType. */
/*M201.errorType = 1		Start scan framing failure */
/*M201.errorType = 2		not enough chars, possible communications error */
/*M201.errorType = 3		Comm port buffer overflow */
/*M201.errorType = 0xA  Scan rate too fast for this scan type */
/* scan status return values 
 SCAN_DONE 0
 SCAN_PENDING 1
 SCAN_TIMEOUT 2
*/
/*
short  GetOneScan(T_M201 *M201);
short  GetOneScan2(T_M201 *M201);
*/
short  GetOneScan(T_M201 *M201);

/*Tell the Model 201 to stop scanning. Returns 0 if Stop scan token is not */
/*echoed back */
short   StopScanning(T_M201 *M201);

/*Get counts from ScanBuffer, scale them in volts, and remove counts from */
/*ScanBuffer */
void   Gconv(T_M201 *M201,
								long *ScanBuffer);

/*Remove size elements from ScanBuffer */
void   RemoveFromBuffer(int size,
								long *ScanBuffer);

/*Set the filter  0 = 4 Hz   1 = 40 Hz   2 = 400 Hz */
void   SetFilter(short filter);

/*Send mode registers to Model 201. Returns 0 if the registers read back */
/*incorrectly */
short  SendADMode(T_M201 *M201);

/*Get and compare Model 201 checksum. Returns 0 if failed, 1 if checksum is OK */
short  GetCheckSum(void);

/*Send the stop scan command to stop a scan if scanning, send master reset, */
/*and close the currently selected comm port. */
short  CloseDevice(void);

/*Put the Model 201 in sleep mode */
/*short  GotoSleep(T_M201 *M201);  */
short  GotoSleep(void);

/*Wait the filter settling time */			 
void   FilterDelay(short filter);

/*Check the selected scan interval to see if it is in limits */
short  CheckScanTime(T_M201 *M201,
								double *maxTime,
								double *minTime);

/*The next two functions only need to be called if
	handling more than one 	Model 201 at a time. */

/*Set the comm handle before CloseDevice */
														 /* TIM NOTE: change for LabView */
void   SetComHandle(int idComDev);

/*----- END OF EXTERNAL FUNCTION PROTOTYPES -*/
/*********************************************/


/* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/


#endif

